@@ -300,6 +300,20 @@ class Snowflakeq:
         else:
             return base_df
 
+    def get_customer_dataset_with_dynamic_pivot_v2(self, customer_name, password,
+                                                now_date='2021-01-01', from_date='2018-01-01'):
+        pre_pvt_df = self.get_data_from_sf('V_GET_CUSTOMER_DATASET_FOR_PIVOT_V2', customer_name, password, now_date, from_date)
+
+        pre_pvt_df['CUSTOMER_ID'] = pre_pvt_df['CUSTOMER_ID'].astype(str)
+
+        pvt_df = pd.pivot_table(pre_pvt_df, values='SALE_QTY', index=['CUSTOMER_ID'],
+                                columns=[f'RANK_PRODUCT_KEY'], aggfunc=np.sum)
+
+        pvt_df.columns = pvt_df.columns.str.upper()
+
+        return pvt_df
+
+
     def get_customer_dataset_agg_prodcut_type_per_order_by_cluster(self, customer_name, password, now_date='2021-01-01',
                                                                    from_date='2018-01-01'):
         pivot_on = 'PRODUCT_TYPE'
